#!/bin/sh
#
# Copies PGM EVK files to the Onlogic device and launches PGM firmware update.
#

PGMFirmware="pgm-v1.3.2.zip"
StarlingProgram="starling-1.16.2-pgm-evk-licensed"

ClearAll=0
UpdatePGM=0
UpdateWiFi=1

if [ "$1" = "CLEARALL" ]; then
  echo All files in swiftnav home directories will be cleared.
  ClearAll=1
  UpdatePGM=1
  UpdateWiFi=1
else
  while true; do
    read -p "WARNING: Existing Starling and other configuration files will be overwritten. Proceed (y/n)? " yn
    case $yn in
        [Yy]* ) break;;
        [Nn]* ) exit;;
        * ) echo "Please answer yes or no.";;
    esac
done
fi

# Check if hostapd exists and install if required
if ! command -v hostapd >/dev/null 2>&1 ; then
  echo The hostapd program is required and will be installed now.
  if ! ping -q -c 1 -W 1 8.8.8.8 >/dev/null; then
    echo "The Internet access is required to install hostapd. Installation aborted."
    exit 1
  else
    echo "Installing hostapd..."
    sudo apt update
    sudo apt install hostapd -y
  fi
fi

echo Stopping services...
sudo systemctl stop starling
sudo systemctl stop swiftnav-pgm
sudo systemctl stop swiftnav-ap

echo Copying files...

sudo cp -v ubuntu-image-files/etc/hostapd/hostapd.conf /etc/hostapd/
sudo cp -v ubuntu-image-files/etc/NetworkManager/NetworkManager.conf /etc/NetworkManager/
sudo cp -v ubuntu-image-files/etc/systemd/network/hostapd.network /etc/systemd/network/
sudo cp -v ubuntu-image-files/etc/udev/rules.d/99-swift-pgm.rules /etc/udev/rules.d/
sudo cp -v ubuntu-image-files/etc/usbmount/usbmount.conf /etc/usbmount/

sudo cp -v ubuntu-image-files/lib/systemd/system/starling.service /lib/systemd/system/
sudo cp -v ubuntu-image-files/lib/systemd/system/starling.target /lib/systemd/system/
sudo cp -v ubuntu-image-files/lib/systemd/system/swiftnav-ap.service /lib/systemd/system/
sudo cp -v ubuntu-image-files/lib/systemd/system/swiftnav-pgm.service /lib/systemd/system/

sudo cp -v ubuntu-image-files/lib/systemd/system/NetworkManager-wait-online.service /lib/systemd/system/
sudo cp -v ubuntu-image-files/lib/systemd/system/systemd-networkd-wait-online.service /lib/systemd/system/


dir="home/swiftnav/cfg"
mkdir -p /$dir
if [ $ClearAll -eq 1 ]; then
  rm -f /$dir/*.*
fi


if [ $UpdateWiFi -eq 1 ]; then
  if [ $ClearAll -eq 0 ]; then
    TimeNow=$(date +"%Y%m%d-%I%M%S")
    mv /$dir/swiftnav-ap.sh /$dir/swiftnav-ap-backup-$TimeNow.sh
    echo Wi-Fi config file saved to swiftnav-ap-backup-$TimeNow.sh
  fi
  cp -v ubuntu-image-files/$dir/swiftnav-ap.sh /$dir
fi

cp -v ubuntu-image-files/$dir/swiftnav-pgm.sh /$dir
chmod 755 /$dir/*.sh

dir="home/swiftnav/pgm"
mkdir -p /$dir
if [ $ClearAll -eq 1 ]; then
  rm -f /$dir/*.*
else
  rm /$dir/pgm-v*.zip
fi
cp -v ubuntu-image-files/$dir/pgm-update.py /$dir
cp -v ubuntu-image-files/$dir/$PGMFirmware /$dir
cp -v ubuntu-image-files/$dir/t.sh /$dir
cp -v ubuntu-image-files/$dir/u.sh /$dir
chmod 755 /$dir/*.sh
chmod 755 /$dir/*.py

dir="home/swiftnav/starling"
mkdir -p /$dir
mkdir -p /$dir/logs
if [ $ClearAll -eq 1 ]; then
  find /$dir/ -type f -not -name "activation-key.txt" -not -name "license.lic" -not -name "starling-guard.json" -delete
  rm -f /$dir/logs/*.*
else
  TimeNow=$(date +"%Y%m%d-%I%M%S")
  mv /$dir/config.yaml /$dir/config-backup-$TimeNow.yaml
  echo Starling config file saved to config-backup-$TimeNow.yaml
  rm -f /$dir/starling
  rm -f /$dir/igs14.atx
fi
cp -v ubuntu-image-files/$dir/config.yaml /$dir
cp -v ubuntu-image-files/$dir/$StarlingProgram /$dir
ln -sf /$dir/$StarlingProgram /$dir/starling
cp -v ubuntu-image-files/$dir/start.sh /$dir
chmod 755 /$dir/$StarlingProgram
chmod 755 /$dir/*.sh

dir="home/swiftnav/tools"
mkdir -p /$dir
if [ $ClearAll -eq 1 ]; then
  rm -f /$dir/*.*
fi
cp -v ubuntu-image-files/$dir/str2str /$dir
chmod 755 /$dir/str2str

dir="home/swiftnav"
if [ $ClearAll -eq 1 ]; then
  rm -f /$dir/*.*
fi
cp -v ubuntu-image-files/$dir/check-for-updates.py /$dir
cp -v ubuntu-image-files/$dir/eth-edit.sh /$dir
cp -v ubuntu-image-files/$dir/starling-edit.sh /$dir
cp -v ubuntu-image-files/$dir/starling-restart.sh /$dir
cp -v ubuntu-image-files/$dir/starling-version.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-connect.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-delete.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-disconnect.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-edit.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-list.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-radio-off.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-radio-on.sh /$dir
cp -v ubuntu-image-files/$dir/wifi-radio-status.sh /$dir
chmod 755 /$dir/*.py
chmod 755 /$dir/*.sh

chmod +w /$dir/version.yaml
cp -v ubuntu-image-files/$dir/version.yaml /$dir

echo Starting services...
sudo systemctl daemon-reload
sudo systemctl restart NetworkManager.service
sudo systemctl start swiftnav-ap
sudo systemctl start swiftnav-pgm
sudo systemctl start starling

sync

if [ $ClearAll -eq 0 ]; then
  while true; do
    read -p "Update also PGM firmware (y/n)? " yn
    case $yn in
        [Yy]* ) UpdatePGM=1; break;;
        [Nn]* ) break;;
        * ) echo "Please answer yes or no.";;
    esac
done
fi

if [ $UpdatePGM -eq 1 ]; then

  echo Updating PGM with $PGMFirmware...

  sh /home/swiftnav/pgm/u.sh /home/swiftnav/pgm/$PGMFirmware

  echo Updating PGM completed.
fi

echo
echo Installation completed.
if [ ! -f "/home/swiftnav/starling/starling-guard.json" ]; then
  echo
  echo WARNING: this Starling version requires a guard file to operate.
  echo Copy starling-guard.json to /home/swiftnav/starling/ directory.
fi
if [ ! -f "/home/swiftnav/starling/activation-key.txt" ]; then
  echo
  echo WARNING: this Starling version requires an activation key file to activate the license.
  echo Write activation key to /home/swiftnav/starling/activation-key.txt file.
  echo "<Place activation key here>" > /home/swiftnav/starling/activation-key.txt
fi
if [ ! -f "/home/swiftnav/starling/license.lic" ]; then
  echo
  echo WARNING: this Starling version requires a license activation to operate.
  echo This device must have access to the Internet to perform the activation procedure.
fi

echo
echo Restart device for all changes to take effect.