#!/usr/bin/env python3

# Checks if PGM EVK files update is available.


import os
import yaml
import json
from requests import get


#==============================================================================
#
#------------------------------------------------------------------------------
def Answered_Yes( question ) :
  while "the answer is invalid":
    reply = str( input(question) ).lower().strip()
    if reply[:1] == 'y':
      return True
    if reply[:1] == 'n':
      return False


#==============================================================================
#
#------------------------------------------------------------------------------
def Version_Tuple( v ) :
  return tuple( map( int, (v.split(".")) ) )



#==============================================================================
#                                   Main
#------------------------------------------------------------------------------

print( "Swift Navigation PGM EVP Update Checker v1.2" )


# Get the current version -------------------------------------------
try:
  f = open( "/home/swiftnav/version.yaml" )
except IOError:
  print( "ERROR: File /home/swiftnav/version.yaml is not present." )
  exit( 1 )

current_version_yaml = yaml.load( f, Loader=yaml.FullLoader )
f.close()

try:
  evk_current_version = current_version_yaml["PGM-EVK-Release"]["Version"]
except KeyError:
  print( "ERROR: No 'Version' key present in /home/swiftnav/version.yaml file." )
  exit( 1 )

print( "Current version: " + evk_current_version )


# Get the latest version --------------------------------------------
response = get( "http://downloads.swiftnav.com/index_https.json" )

latest_version_json = json.loads( response.content )

evk_latest_version = latest_version_json["pgm-evp-onlogic"]["fw"]["version"]

print( "Latest version:  " + evk_latest_version )


# Compare versions and download update ------------------------------
if Version_Tuple( evk_latest_version[1:] ) > Version_Tuple( evk_current_version[1:] ) :
  print( "Software update is available." )
  print( "Warning: by downloading the new software you agree to the Terms and Conditions posted on Swift Navigation portal:" )
  print( "'https://www.swiftnav.com/resource-files/Starling/v1/Legal/Starling and Skylark Terms and Conditions v1.pdf'" )

  if Answered_Yes( "Proceed with the download (y/n)? " ) :
    download_url = latest_version_json["pgm-evp-onlogic"]["fw"]["url"]
    destination_dir = "/home/swiftnav/updates/" + evk_latest_version + "/"
    os.system( "wget -N -q --show-progress --content-disposition -P " + destination_dir + " " + download_url )
    print( "New release saved in: " + destination_dir )

    if Answered_Yes( "Proceed with the installation (y/n)? " ) :
      print( "Installing..." )
      os.chdir( destination_dir )
      os.system( "tar -xvf " + download_url.split("/")[-1] )
      os.system( "./install-update.sh" )

elif evk_latest_version == evk_current_version :
  print( "You have the latest version already." )

else :
  print( "Your current version is newer than the latest version published." )
